@@ -4,38 +4,36 @@ use warnings;
 
 package Dist::Zilla::Plugin::InstallGuide;
 BEGIN {
-  $Dist::Zilla::Plugin::InstallGuide::VERSION = '1.101420';
+  $Dist::Zilla::Plugin::InstallGuide::VERSION = '1.101460';
 }
 
 # ABSTRACT: Build an INSTALL file
 use Moose;
 use Moose::Autobox;
-with 'Dist::Zilla::Role::FileGatherer';
+with 'Dist::Zilla::Role::InstallTool';
 with 'Dist::Zilla::Role::TextTemplate';
 
-sub gather_files {
-    my $self = shift;
-    require Dist::Zilla::File::InMemory;
-    (my $main_package = $self->zilla->name) =~ s!-!::!g;
-    my $template = q|
+my $template = q|
 This is the Perl distribution {{ $dist->name }}.
 
 ## Installation
 
 {{ $dist->name }} installation is straightforward.
-If your CPAN shell is set up, you should just be able to do
+
+### Installation with cpanm
+
+If you have cpanm, you only need one line:
+
+    % cpanm {{ $package }}
+
+### Installating with the CPAN shell
+
+Alternatively, if your CPAN shell is set up, you should just be able to do:
 
     % cpan {{ $package }}
 
-Download it, unpack it, then build it as per the usual:
-
-    % perl Makefile.PL
-    % make && make test
-
-Then install it:
-
-    % make install
-
+### Manual installation
+{{ $manual_installation }}
 ## Documentation
 
 {{ $dist->name }} documentation is available as in POD.
@@ -45,10 +43,53 @@ So you can do:
 
 to read the documentation with your favorite pager.
 |;
+
+my $makemaker_manual_installation = q|
+As a last resort, you can manually install it. Download it, unpack it, then
+build it as per the usual:
+
+    % perl Makefile.PL
+    % make && make test
+
+Then install it:
+
+    % make install
+|;
+
+my $module_build_manual_installation = q|
+As a last resort, you can manually install it. Download it, unpack it, then
+build it:
+
+    % perl Build.PL
+    % ./Build && ./Build test
+
+Then install it:
+
+    % ./Build install
+|;
+
+sub setup_installer {
+    my $self = shift;
+    my $manual_installation;
+    for (@{ $self->zilla->files }) {
+        if ($_->name eq 'Makefile.PL') {
+            $manual_installation = $makemaker_manual_installation;
+            last;
+        } elsif ($_->name eq 'Build.PL') {
+            $manual_installation = $module_build_manual_installation;
+            last;
+        }
+    }
+    unless (defined $manual_installation) {
+        $self->log_fatal('neither Makefile.PL nor Build.PL is present, aborting');
+    }
+    require Dist::Zilla::File::InMemory;
+    (my $main_package = $self->zilla->name) =~ s!-!::!g;
     my $content = $self->fill_in_string(
         $template,
-        {   dist    => \($self->zilla),
-            package => $main_package
+        {   dist                => \($self->zilla),
+            package             => $main_package,
+            manual_installation => $manual_installation
         }
     );
     my $file = Dist::Zilla::File::InMemory->new(
@@ -73,7 +114,7 @@ Dist::Zilla::Plugin::InstallGuide - Build an INSTALL file
 
 =head1 VERSION
 
-version 1.101420
+version 1.101460
 
 =head1 SYNOPSIS
 
@@ -86,9 +127,14 @@ In C<dist.ini>:
 This plugin adds a very simple F<INSTALL> file to the distribution, telling
 the user how to install this distribution.
 
+You should use this plugin in your L<Dist::Zilla> configuration after
+C<[MakeMaker]> or C<[ModuleBuild]> so that it can determine what kind of
+distribution you are building and which installation instructions are
+appropriate.
+
 =head1 FUNCTIONS
 
-=head2 gather_files
+=head2 setup_installer
 
 Builds and writes the C<INSTALL> file.
 
